pub struct SetParams(pub CameraParams);Expand description
Set camera parameters (wraps CameraParams)
Tuple Fields
0: CameraParamsTrait Implementations
Sourceimpl Archive for SetParamswhere
CameraParams: Archive,
impl Archive for SetParamswhere
CameraParams: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSetParams
type Archived = ArchivedSetParams
The archived representation of this type. Read more
Sourcetype Resolver = SetParamsResolver
type Resolver = SetParamsResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SetParamswhere
CameraParams: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SetParamswhere
CameraParams: Serialize<__S>,
impl Archive for SetParams