CameraApi

Struct CameraApi 

pub struct CameraApi<P: CheckedPermissions>(/* private fields */);

Implementations

Source

impl<P: CheckedPermissions> CameraApi<P>

pub fn try_new_with_timeout(timeout: Duration) -> Option<Self>

Permission: none

pub fn subscribe<S>( &self, context: &mut ServerContext<S>, ) -> Result<(), SubscriptionError>
where S: Server + ScalarEventHandler<Frame>, P: MessageAllowed<Subscribe>,

Permission: os/camera / Subscribe

Groups: peripherals.camera-use

Sender policy: signed

Grant timing: grant-on-first-use, while-active

Start requesting camera frames. Cheap because the frames are not actually sent, but mirrored on the client side. The event is sent when a new frame is available.

pub fn set_enabled(&self, enabled: bool)
where P: MessageAllowed<SetEnabled>,

Permission: os/camera / SetEnabled

Groups: peripherals.camera-control

Sender policy: foundation-signed

Grant timing: policy-only

Enable the use of the camera. Intended to be used by the control center

pub fn notify_visible(&self, visible: bool)
where P: MessageAllowed<NotifyVisible>,

Permission: os/camera / NotifyVisible

Groups: peripherals.camera-use

Sender policy: signed

Grant timing: grant-on-first-use, while-active

Notify the app that the camera image is visible on the screen. Intended to be used by the GUI server

pub fn is_enabled(&self) -> bool
where P: MessageAllowed<IsEnabled>,

Permission: os/camera / IsEnabled

Groups: peripherals.camera-status

Sender policy: signed

Grant timing: install-review

pub fn is_in_use(&self) -> bool
where P: MessageAllowed<IsInUse>,

Permission: os/camera / IsInUse

Groups: peripherals.camera-status

Sender policy: signed

Grant timing: install-review

pub fn get_params(&self) -> Result<CameraParams, Error>
where P: MessageAllowed<GetParams>,

Permission: os/camera / GetParams

Groups: peripherals.camera-use

Sender policy: signed

Grant timing: grant-on-first-use, while-active

Get current camera parameters

pub fn set_params(&self, params: CameraParams) -> Result<(), Error>
where P: MessageAllowed<SetParams>,

Permission: os/camera / SetParams

Groups: peripherals.camera-use

Sender policy: signed

Grant timing: grant-on-first-use, while-active

Set camera parameters