pub struct CameraApi<P: CheckedPermissions>(/* private fields */);Implementations
Sourceimpl<P: CheckedPermissions> CameraApi<P>
impl<P: CheckedPermissions> CameraApi<P>
pub fn try_new_with_timeout(timeout: Duration) -> Option<Self>
Sourcepub fn subscribe<S>(
&self,
context: &mut ServerContext<S>,
) -> Result<(), SubscriptionError>
pub fn subscribe<S>( &self, context: &mut ServerContext<S>, ) -> Result<(), SubscriptionError>
Start requesting camera frames. Cheap because the frames are not actually sent, but mirrored on the client side. The event is sent when a new frame is available.
pub fn is_enabled(&self) -> boolwhere
P: MessageAllowed<IsEnabled>,
pub fn is_in_use(&self) -> boolwhere
P: MessageAllowed<IsInUse>,